package jalview.gui;

import jalview.jbgui.*;
import jalview.schemes.*;

import jalview.bin.Cache;
import javax.swing.*;
import java.awt.event.ActionEvent;
import java.awt.*;

public class Preferences extends GPreferences
{
  static boolean preferencesLoaded=false;

  public static boolean showFullscreen=false;
  public static boolean showFullId=true;
  public static boolean showAnnotation=true;
  public static boolean showConservation=true;
  public static boolean showQuality=true;
  public static boolean showIdentity=true;
  public static String fontName;
  public static String fontSize;
  public static String fontStyle;
  public static char gapSymbol='-';
  public static String defaultColour=null;

  JInternalFrame frame;

  public static void initPreferences()
  {
  String string = Cache.getProperty("SHOW_FULL_ID");
  if(string!=null)
    showFullId = Boolean.valueOf(string).booleanValue();

  string = Cache.getProperty("SHOW_FULLSCREEN");
  if(string!=null)
    showFullscreen = Boolean.valueOf(string).booleanValue();


  string = Cache.getProperty("SHOW_ANNOTATIONS");
      if(string!=null)
    showAnnotation = Boolean.valueOf(string).booleanValue();

  string = Cache.getProperty("SHOW_CONSERVATION");
      if(string!=null)
    showConservation = Boolean.valueOf(string).booleanValue();
  string = Cache.getProperty("SHOW_QUALITY");
      if(string!=null)
    showQuality = Boolean.valueOf(string).booleanValue();
  string = Cache.getProperty("SHOW_IDENTITY");
      if(string!=null)
    showIdentity = Boolean.valueOf(string).booleanValue();

  string = Cache.getProperty("SHOW_FULL_ID");
    if(string!=null)
      showFullId = Boolean.valueOf(string).booleanValue();

  fontName = Cache.getProperty("FONT_NAME");
  fontStyle = Cache.getProperty("FONT_STYLE");
  fontSize = Cache.getProperty("FONT_SIZE");

      preferencesLoaded = true;
  }

  public Preferences()
  {
    if(!preferencesLoaded)
      initPreferences();

    frame = new JInternalFrame();
    frame.setContentPane(this);
    Desktop.addInternalFrame(frame, "Preferences", 480,350 );

    fullID.setSelected(showFullId);
    String string = Cache.getProperty("SHOW_FULLSCREEN");
    boolean value = false;
    if(string!=null)
      value =  Boolean.valueOf(string).booleanValue();

    fullScreen.setSelected(value);
    annotations.setSelected(showAnnotation);

    conservation.setEnabled(showAnnotation);
    quality.setEnabled(showAnnotation);
    identity.setEnabled(showAnnotation);

    conservation.setSelected(showConservation);
    quality.setSelected(showQuality);
    identity.setSelected(showIdentity);

    for(int i=0; i<12; i++)
      colour.addItem( ColourSchemeProperty.getColourName(i) );

    string = Cache.getProperty("DEFAULT_COLOUR");
    if(string!=null)
      colour.setSelectedItem( string );
    else
      colour.setSelectedIndex( 11 );

    String fonts[] = java.awt.GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames();
    for(int i=0; i<fonts.length; i++)
      fontNameCB.addItem(fonts[i]);

    for(int i=1; i<31; i++)
      fontSizeCB.addItem(i+"");

   fontStyleCB.addItem("plain");
   fontStyleCB.addItem("bold");
   fontStyleCB.addItem("italic");

   fontNameCB.setSelectedItem(fontName);
   fontSizeCB.setSelectedItem(fontSize);
   fontStyleCB.setSelectedItem(fontStyle);

   gapSymbolCB.addItem("-");
   gapSymbolCB.addItem(".");

   gapSymbolCB.setSelectedItem( gapSymbol+"" );

  }

  public void ok_actionPerformed(ActionEvent e)
  {
    showFullId =  fullID.isSelected() ;
    showFullscreen = fullScreen.isSelected();
    showAnnotation = annotations.isSelected();
    showConservation = conservation.isSelected();
    showQuality = quality.isSelected();
    showIdentity = identity.isSelected();
    defaultColour = colour.getSelectedItem().toString();
    gapSymbol = gapSymbolCB.getSelectedItem().toString().charAt(0);
    fontName = fontNameCB.getSelectedItem().toString();
    fontSize = fontSizeCB.getSelectedItem().toString();
    fontStyle = fontStyleCB.getSelectedItem().toString();

    Cache.setProperty("SHOW_FULL_ID", Boolean.toString(showFullId));
    Cache.setProperty("SHOW_FULLSCREEN", Boolean.toString( showFullscreen ) );

    Cache.setProperty("SHOW_ANNOTATIONS", Boolean.toString( showAnnotation  ));
    Cache.setProperty("SHOW_CONSERVATION", Boolean.toString( showConservation ));
    Cache.setProperty("SHOW_QUALITY", Boolean.toString( showQuality ));
    Cache.setProperty("SHOW_IDENTITY", Boolean.toString( showIdentity ));

    Cache.setProperty("DEFAULT_COLOUR", defaultColour);
    Cache.setProperty("GAP_SYMBOL", gapSymbol+"");

    Cache.setProperty("FONT_NAME", fontName);
    Cache.setProperty("FONT_STYLE", fontStyle);
    Cache.setProperty("FONT_SIZE", fontSize);

    try    {
      frame.setClosed(true);
    }    catch (Exception ex)  {}

  }

  public void cancel_actionPerformed(ActionEvent e)
  {
    try{
      frame.setClosed(true);
    }catch(Exception ex){}
  }

  public void annotations_actionPerformed(ActionEvent e)
  {
    conservation.setEnabled(annotations.isSelected());
    quality.setEnabled(annotations.isSelected());
    identity.setEnabled(annotations.isSelected());
  }

}
